# AppliedConnectorStatsConfig

The applied configuration for a connector's stats collection. This can change frequently, since some of it is time-bound, so fetching it in an event-driven fashion is recommended. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**publishing** | [**StatsPublishingConnectorConfig**](StatsPublishingConnectorConfig.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


